@@ -1,4 +1,4 @@
-from pinotdb.db import connect
+from pinotdb.db import connect, connect_async
 from pinotdb.exceptions import (
     DataError,
     DatabaseError,
@@ -15,6 +15,7 @@ from pinotdb.exceptions import (
 
 __all__ = [
     "connect",
+    "connect_async",
     "apilevel",
     "threadsafety",
     "paramstyle",
